<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="pl_PL">
<context>
    <name>QStarDict::CSSEdit</name>
    <message>
        <location filename="../cssedit.ui" line="16"/>
        <source>Preview</source>
        <translation>Podgląd</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="30"/>
        <source>Element</source>
        <translation>Element</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="37"/>
        <source>Foreground</source>
        <translation>Pierwszy plan</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="44"/>
        <source>Background</source>
        <translation>Tło</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="51"/>
        <source>Select element</source>
        <translation>Wybierz element</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="68"/>
        <source>Click to select color</source>
        <translation>Kliknij by wybrać kolor</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="71"/>
        <source>#000000</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="78"/>
        <source>Font</source>
        <translation>Czcionka</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="85"/>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="92"/>
        <source>Select font</source>
        <translation>Wybierz czcionkę</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="99"/>
        <source>Select font size</source>
        <translation>Wybierz rozmiar czionki</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="102"/>
        <source>pt</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="127"/>
        <source>Bold</source>
        <translation>Pogrubiona</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="130"/>
        <source>B</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="147"/>
        <source>Italic</source>
        <translation>Pochyła</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="150"/>
        <source>I</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="167"/>
        <source>Underline</source>
        <translation>Podkreślona</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="170"/>
        <source>U</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QStarDict::DictBrowser</name>
    <message>
        <location filename="../dictbrowser.cpp" line="72"/>
        <source>The word &lt;b&gt;%1&lt;/b&gt; is not found.</source>
        <translation>Słowo &lt;b&gt;%1&lt;/b&gt; nie zostało znalezione.</translation>
    </message>
</context>
<context>
    <name>QStarDict::DictWidget</name>
    <message>
        <location filename="../dictwidget.cpp" line="114"/>
        <source>Save translation</source>
        <translation>Zapisz tłumaczenie</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="135"/>
        <source>HTML files (*.html, *.htm)</source>
        <translation>Pliki HTML (*.html, *.htm)</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="124"/>
        <source>Text files (*.txt)</source>
        <translation>Pliki tekstowe (*.txt)</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="130"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="131"/>
        <source>Cannot save translation as %1</source>
        <translation>Nie mogę zapisać tłumaczenia jako %1</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="75"/>
        <source>Go to &amp;previous translation</source>
        <translation>Idź do &amp;poprzedniego tłumaczenia</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="80"/>
        <source>Go to &amp;next translation</source>
        <translation>Idź do &amp;następnego tłumaczenia</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="85"/>
        <source>&amp;Save to file</source>
        <translation>&amp;Zapisz do pliku</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="91"/>
        <source>Speak &amp;word</source>
        <translation>Wymów sło&amp;wo</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="88"/>
        <source>Prin&amp;t translation</source>
        <translation>Drukuj &amp;tłumaczenie</translation>
    </message>
</context>
<context>
    <name>QStarDict::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="114"/>
        <source>About QStarDict</source>
        <translation>O QStarDict</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="115"/>
        <source>&lt;b&gt;QStarDict %1 &lt;/b&gt; - Qt version of StarDict&lt;br&gt;</source>
        <translation>&lt;b&gt;QStarDict %1 &lt;/b&gt; - StarDict wersja QT&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="117"/>
        <source>Copyright (C) 2007 Alexander Rodin &lt;a href=&quot;http://qstardict.ylsoftware.com&quot;&gt;http://qstardict.ylsoftware.com&lt;/a&gt;</source>
        <translation>Copyright (C) 2007 Alexander Rodin &lt;a href=&quot;http://qstardict.ylsoftware.com&quot;&gt;http://qstardict.ylsoftware.com&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="13"/>
        <source>QStarDict</source>
        <translation>QStarDict</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="183"/>
        <source>%1 - QStarDict</source>
        <translation>%1 - QStarDict</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>Clear the search box</source>
        <translation>Wyczyść okienko wyszukiwania</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="61"/>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="77"/>
        <source>Fuzzy query</source>
        <translation>Mętne zapytanie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="80"/>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Words list</source>
        <translation>Lista słów</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="147"/>
        <source>&amp;File</source>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>&amp;Settings</source>
        <translation>&amp;Ustawienia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <source>&amp;Quit</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>&amp;About</source>
        <translation>&amp;O QStarDict</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="187"/>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="195"/>
        <source>&amp;Configure QStarDict</source>
        <translation>&amp;Konfiguruj QStarDict</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>&amp;Scan</source>
        <translation>&amp;Skanuj</translation>
    </message>
</context>
<context>
    <name>QStarDict::SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="68"/>
        <source>Enabled</source>
        <translation>Włączone</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="68"/>
        <source>Name</source>
        <translation>Imię</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="68"/>
        <source>Plugin</source>
        <translation>Wtyczka</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="261"/>
        <source>Information about dictionary &quot;%1&quot;</source>
        <translation>Informacja o słowniku &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="279"/>
        <source>&lt;b&gt;Name:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Imię:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="263"/>
        <source>&lt;b&gt;Plugin:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Wtyczka:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="265"/>
        <source>unknown</source>
        <translation>nieznany</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="283"/>
        <source>&lt;b&gt;Description:&lt;/b&gt; %1</source>
        <translation>&lt;b&gt;Opis:&lt;/b&gt; %1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="278"/>
        <source>Information about %1 plugin</source>
        <translation>Informację o wtyczce %1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="280"/>
        <source>&lt;b&gt;Version:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Wersja:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="281"/>
        <source>&lt;b&gt;Authors:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Autorzy:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="281"/>
        <source>&lt;br&gt;</source>
        <translation>&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="282"/>
        <source>&lt;b&gt;Can search similar words:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Może wyszukać podobne słowa:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="282"/>
        <source>yes</source>
        <translation>tak</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="282"/>
        <source>no</source>
        <translation>nie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>QStarDict Settings</source>
        <translation>Ustawienia QStarDict</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="16"/>
        <source>Show information about dictionary</source>
        <translation>Pokaż informacje o słowniku</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Global settings</source>
        <translation>Globalne opcje</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Instant search</source>
        <translation>Błyskawiczne szukanie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="87"/>
        <source>Pronounce words using this command:</source>
        <translation>Wymów słowo używając tego polecenia:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Enter cmd for the speaching program.&lt;br&gt;If cmd contains &quot;%s&quot; it will be replaced to word, else word will be writen to stdin of speech process.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="123"/>
        <source>Dictionaries</source>
        <translation>Słowniki</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="147"/>
        <source>Move up</source>
        <translation>Przesuń w górę</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="150"/>
        <source>Up</source>
        <translation>Góra</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="160"/>
        <source>Move down</source>
        <translation>Przesuń w dół</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="163"/>
        <source>Down</source>
        <translation>Dół</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="173"/>
        <source>Show info</source>
        <translation>Pokaż info</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="207"/>
        <source>Plugins</source>
        <translation>Wtyczki</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="234"/>
        <source>Show information about plugin</source>
        <translation>Pokaż informacje o wtyczce</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="237"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="247"/>
        <source>Configure plugin</source>
        <translation>Konfiguruj wtyczkę</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="250"/>
        <source>Configure</source>
        <translation>Konfiguruj</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="279"/>
        <source>Popup window</source>
        <translation>Okno popup</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="303"/>
        <source>Behavior</source>
        <translation>Zachowanie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="344"/>
        <source>Pronounce the word</source>
        <translation>Wymów słowo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="370"/>
        <source>Timeout before hide after mouse over</source>
        <translation>Opóźnienie zanim ukryje po najechaniu myszką</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="377"/>
        <source>Don&apos;t hide</source>
        <translation>Nie ukrywaj</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="380"/>
        <source> sec</source>
        <translation> sec</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="424"/>
        <source>Show only if modifier pressed</source>
        <translation>Pokaż tylko jeśli modyfikator zostanie naciśnięty</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="435"/>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="440"/>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="445"/>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="450"/>
        <source>Win</source>
        <translation>Win</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="460"/>
        <source>Scan selection</source>
        <translation>Skanuj zaznaczenie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="470"/>
        <source>Show if word not found</source>
        <translation>Pokaż jeśli słowo nie zostało znalezione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="644"/>
        <source>Apperance</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="521"/>
        <source>Opacity</source>
        <translation>Nieprzezroczystość</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="528"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="566"/>
        <source>Default width</source>
        <translation>Domyślna szerokość</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="605"/>
        <source>Default height</source>
        <translation>Domyślna wysokość</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="264"/>
        <source>&lt;b&gt;Author:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Autor:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="265"/>
        <source>&lt;b&gt;Words count:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation>&lt;b&gt;Ilość słów:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="113"/>
        <source>All translation</source>
        <translation>Wszystkie tłumaczenia</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="114"/>
        <source>Dictionary name</source>
        <translation>Nazwa słownika</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="115"/>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="116"/>
        <source>Explanation</source>
        <translation>Wytłumaczenie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="117"/>
        <source>Abbreviation</source>
        <translation>Skrót</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="118"/>
        <source>Example</source>
        <translation>Przykład</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="119"/>
        <source>Transcription</source>
        <translation>Transkrypcja</translation>
    </message>
</context>
<context>
    <name>QStarDict::TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="36"/>
        <source>QStarDict</source>
        <translation>QStarDict</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="37"/>
        <source>&amp;Scan</source>
        <translation>&amp;Skanuj</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="47"/>
        <source>&amp;Configure QStarDict</source>
        <translation>&amp;Konfiguruj QStarDict</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="50"/>
        <source>&amp;Quit</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="84"/>
        <source>QStarDict: scanning is %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="84"/>
        <source>enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="84"/>
        <source>disabled</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
